@@ -1,21 +1,11 @@
-/***************************************************************************
-                     read a KEduVocDocument from a KVTML file
-    -----------------------------------------------------------------------
-    copyright           : (C) 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
-
-                          (C) 2005 Eric Pignet <eric at erixpage.com>
-                          (C) 2007 Peter Hedlund <peter.hedlund@kdemail.net>
-    Copyright 2007-2010 Frederik Gladhorn <gladhorn@kde.org>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * read a KEduVocDocument from a KVTML file
+ * SPDX-FileCopyrightText: 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
+ * SPDX-FileCopyrightText: 2005 Eric Pignet <eric at erixpage.com>
+ * SPDX-FileCopyrightText: 2007 Peter Hedlund <peter.hedlund@kdemail.net>
+ * SPDX-FileCopyrightText: 2007-2010 Frederik Gladhorn <gladhorn@kde.org>
+ * SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "keduvockvtml2reader.h"
 
